import React, { useRef, useState } from 'react';
import { Dimensions, ImageBackground, Modal, SafeAreaView, StyleSheet, Text, TouchableOpacity, View, } from 'react-native';
import { Page } from './Page';
import { SwiperFlatList } from './Swiper';
import { COLOR_PAGINATION_DEFAULT, COLOR_PAGINATION_SELECTED_DEFAULT, HORIZONTAL_PADDING_DEFAULT, VERTICAL_PADDING_DEFAULT, } from '../constants';
import { PrimaryButton } from './components/PrimaryButton';
import { Footer } from './Footer';
import { SecondaryButton } from './components/SecondaryButton';
import { DotPagination } from './Pagination/components/Dot';
export const OnboardFlow = ({ backgroundImageUri, dismissButtonStyle, fullscreenModal = true, onBack, onDone, onNext, pageStyle, pageTypes = {}, pages, paginationColor = COLOR_PAGINATION_DEFAULT, paginationSelectedColor = COLOR_PAGINATION_SELECTED_DEFAULT, showDismissButton = false, style, subtitleStyle, textAlign = 'center', titleStyle, FooterComponent = Footer, PaginationComponent = DotPagination, PrimaryButtonComponent = PrimaryButton, SecondaryButtonComponent = SecondaryButton, ...props }) => {
    const [currentPage, setCurrentPage] = useState(0);
    const [modalVisible, setModalVisible] = useState(true);
    const swiperRef = useRef();
    const [width, setWidth] = useState(Dimensions.get('window').width ?? 0);
    const [height, setHeight] = useState(Dimensions.get('window').height ?? 0);
    const components = {
        PrimaryButtonComponent,
        PaginationComponent,
        SecondaryButtonComponent,
    };
    const onLayout = (event) => {
        setWidth(event.nativeEvent.layout.width);
        setHeight(event.nativeEvent.layout.height);
    };
    function handleIndexChange(item) {
        if (item.index != currentPage) {
            setCurrentPage(item.index);
        }
        if (item.index > item.prevIndex) {
            onNext && onNext();
            return;
        }
        if (item.index < item.prevIndex) {
            onBack && onBack();
            return;
        }
    }
    function handleDone() {
        setModalVisible(false);
        onDone && onDone();
    }
    function goToNextPage() {
        if (currentPage >= pages?.length - 1) {
            handleDone();
            return;
        }
        const nextIndex = swiperRef.current?.getCurrentIndex() + 1;
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function goToPreviousPage() {
        const nextIndex = swiperRef.current?.getCurrentIndex() - 1;
        if (nextIndex < 0) {
            return;
        }
        setCurrentPage(nextIndex);
        swiperRef.current?.scrollToIndex({ index: nextIndex });
    }
    function DismissButton() {
        return (<View style={[styles.dismissIconContainer, dismissButtonStyle]}>
      <TouchableOpacity onPress={handleDone}>
        <Text style={styles.dismissIcon}>✕</Text>
      </TouchableOpacity>
    </View>);
    }
    const content = <ImageBackground source={{ uri: backgroundImageUri }} resizeMode='cover' style={styles.backgroundImage}>
    <SafeAreaView style={[styles.container, style]} onLayout={onLayout}>
      {showDismissButton && <DismissButton />}
      <View style={styles.content}>
        <SwiperFlatList onChangeIndex={handleIndexChange} ref={swiperRef} index={currentPage}>
          {pages?.map((pageData, index) => (pageData.type && pageTypes[pageData.type] ?
            <View key={index}>{pageTypes[pageData.type]({
                    pageProps: {
                        style: pageStyle,
                        titleStyle,
                        subtitleStyle,
                        pageData,
                        currentPage,
                        totalPages: pages?.length,
                        goToNextPage,
                        goToPreviousPage,
                        textAlign,
                        width,
                    }, props: pageData.props,
                })}</View> :
            <View key={index}>
                <Page style={pageStyle} titleStyle={titleStyle} subtitleStyle={subtitleStyle} pageData={pageData} currentPage={currentPage} totalPages={pages?.length} goToNextPage={goToNextPage} goToPreviousPage={goToPreviousPage} textAlign={textAlign} width={width}/>
              </View>))}
        </SwiperFlatList>
      </View>
      <FooterComponent goToPreviousPage={goToPreviousPage} pages={pages} style={styles.footer} Components={components} currentPage={currentPage} goToNextPage={goToNextPage}/>
    </SafeAreaView>
  </ImageBackground>;
    if (!fullscreenModal) {
        return content;
    }
    return (<Modal visible={modalVisible}>
      {content}
    </Modal>);
};
const styles = StyleSheet.create({
    footer: {
        flex: 1,
        paddingHorizontal: HORIZONTAL_PADDING_DEFAULT,
        justifyContent: 'flex-end',
        flexDirection: 'column',
    },
    button: {
        backgroundColor: '#000',
        width: '100%',
        borderRadius: 32,
        marginTop: VERTICAL_PADDING_DEFAULT,
        marginBottom: VERTICAL_PADDING_DEFAULT,
    },
    buttonText: {
        color: '#fff',
        fontSize: 18,
        fontWeight: '500',
        textAlign: 'center',
        paddingVertical: VERTICAL_PADDING_DEFAULT,
    },
    container: {
        flex: 1,
        flexDirection: 'column',
        justifyContent: 'space-between',
        alignItems: 'stretch',
        alignContent: 'space-between',
    },
    content: {
        flex: 1,
        flexGrow: 4,
    },
    backgroundImage: {
        flex: 1,
    },
    buttonBackgroundImage: {
        borderRadius: 32,
        marginHorizontal: 32,
    },
    dismissIcon: {
        fontSize: 22,
        width: 30,
        height: 30,
        textAlign: 'center',
        lineHeight: 30,
        backgroundColor: 'transparent',
    },
    dismissIconContainer: {
        position: 'absolute',
        flex: 1,
        top: VERTICAL_PADDING_DEFAULT * 2,
        right: HORIZONTAL_PADDING_DEFAULT,
        zIndex: 5,
    },
});
